==> zio-aws-machinelearning_2.12-5.17.123.1-sources.jar: zio/aws/machinelearning/model/CreateDataSourceFromRdsRequest.scala <==
package zio.aws.machinelearning.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.machinelearning.model.primitives.{
  ComputeStatistics,
  RoleARN,
  EntityName,
  EntityId
}
import scala.jdk.CollectionConverters._
final case class CreateDataSourceFromRdsRequest(
    dataSourceId: EntityId,
    dataSourceName: Option[EntityName] = None,
    rdsData: zio.aws.machinelearning.model.RDSDataSpec,
    roleARN: RoleARN,
    computeStatistics: Option[ComputeStatistics] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.machinelearning.model.CreateDataSourceFromRdsRequest = {
    import CreateDataSourceFromRdsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.machinelearning.model.CreateDataSourceFromRdsRequest
      .builder()
      .dataSourceId(EntityId.unwrap(dataSourceId): java.lang.String)
      .optionallyWith(
        dataSourceName.map(value => EntityName.unwrap(value): java.lang.String)
      )(_.dataSourceName)
      .rdsData(rdsData.buildAwsValue())
      .roleARN(RoleARN.unwrap(roleARN): java.lang.String)
      .optionallyWith(
        computeStatistics.map(value =>
          ComputeStatistics.unwrap(value): java.lang.Boolean
        )
      )(_.computeStatistics)
      .build()
  }
  def asReadOnly
      : zio.aws.machinelearning.model.CreateDataSourceFromRdsRequest.ReadOnly =
    zio.aws.machinelearning.model.CreateDataSourceFromRdsRequest
      .wrap(buildAwsValue())
}
object CreateDataSourceFromRdsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.machinelearning.model.CreateDataSourceFromRdsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.machinelearning.model.CreateDataSourceFromRdsRequest =
      zio.aws.machinelearning.model.CreateDataSourceFromRdsRequest(
        dataSourceId,
        dataSourceName.map(value => value),
        rdsData.asEditable,
        roleARN,
        computeStatistics.map(value => value)
      )
    def dataSourceId: EntityId
    def dataSourceName: Option[EntityName]
    def rdsData: zio.aws.machinelearning.model.RDSDataSpec.ReadOnly
    def roleARN: RoleARN
    def computeStatistics: Option[ComputeStatistics]
    def getDataSourceId: ZIO[Any, Nothing, EntityId] = ZIO.succeed(dataSourceId)
    def getDataSourceName: ZIO[Any, AwsError, EntityName] =
      AwsError.unwrapOptionField("dataSourceName", dataSourceName)
    def getRdsData: ZIO[
      Any,
      Nothing,
      zio.aws.machinelearning.model.RDSDataSpec.ReadOnly
    ] = ZIO.succeed(rdsData)
    def getRoleARN: ZIO[Any, Nothing, RoleARN] = ZIO.succeed(roleARN)
    def getComputeStatistics: ZIO[Any, AwsError, ComputeStatistics] =
      AwsError.unwrapOptionField("computeStatistics", computeStatistics)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.machinelearning.model.CreateDataSourceFromRdsRequest
  ) extends zio.aws.machinelearning.model.CreateDataSourceFromRdsRequest.ReadOnly {
    override val dataSourceId: EntityId =
      zio.aws.machinelearning.model.primitives.EntityId(impl.dataSourceId())
    override val dataSourceName: Option[EntityName] = scala
      .Option(impl.dataSourceName())
      .map(value => zio.aws.machinelearning.model.primitives.EntityName(value))
    override val rdsData: zio.aws.machinelearning.model.RDSDataSpec.ReadOnly =
      zio.aws.machinelearning.model.RDSDataSpec.wrap(impl.rdsData())
    override val roleARN: RoleARN =
      zio.aws.machinelearning.model.primitives.RoleARN(impl.roleARN())
    override val computeStatistics: Option[ComputeStatistics] = scala
      .Option(impl.computeStatistics())
      .map(value =>
        zio.aws.machinelearning.model.primitives.ComputeStatistics(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.machinelearning.model.CreateDataSourceFromRdsRequest
  ): zio.aws.machinelearning.model.CreateDataSourceFromRdsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-machinelearning_2.13-5.17.203.2-sources.jar: zio/aws/machinelearning/model/CreateDataSourceFromRdsRequest.scala <==
package zio.aws.machinelearning.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.machinelearning.model.primitives.{
  ComputeStatistics,
  RoleARN,
  EntityName,
  EntityId
}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateDataSourceFromRdsRequest(
    dataSourceId: EntityId,
    dataSourceName: Optional[EntityName] = Optional.Absent,
    rdsData: zio.aws.machinelearning.model.RDSDataSpec,
    roleARN: RoleARN,
    computeStatistics: Optional[ComputeStatistics] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.machinelearning.model.CreateDataSourceFromRdsRequest = {
    import CreateDataSourceFromRdsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.machinelearning.model.CreateDataSourceFromRdsRequest
      .builder()
      .dataSourceId(EntityId.unwrap(dataSourceId): java.lang.String)
      .optionallyWith(
        dataSourceName.map(value => EntityName.unwrap(value): java.lang.String)
      )(_.dataSourceName)
      .rdsData(rdsData.buildAwsValue())
      .roleARN(RoleARN.unwrap(roleARN): java.lang.String)
      .optionallyWith(
        computeStatistics.map(value =>
          ComputeStatistics.unwrap(value): java.lang.Boolean
        )
      )(_.computeStatistics)
      .build()
  }
  def asReadOnly
      : zio.aws.machinelearning.model.CreateDataSourceFromRdsRequest.ReadOnly =
    zio.aws.machinelearning.model.CreateDataSourceFromRdsRequest
      .wrap(buildAwsValue())
}
object CreateDataSourceFromRdsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.machinelearning.model.CreateDataSourceFromRdsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.machinelearning.model.CreateDataSourceFromRdsRequest =
      zio.aws.machinelearning.model.CreateDataSourceFromRdsRequest(
        dataSourceId,
        dataSourceName.map(value => value),
        rdsData.asEditable,
        roleARN,
        computeStatistics.map(value => value)
      )
    def dataSourceId: EntityId
    def dataSourceName: Optional[EntityName]
    def rdsData: zio.aws.machinelearning.model.RDSDataSpec.ReadOnly
    def roleARN: RoleARN
    def computeStatistics: Optional[ComputeStatistics]
    def getDataSourceId: ZIO[Any, Nothing, EntityId] = ZIO.succeed(dataSourceId)
    def getDataSourceName: ZIO[Any, AwsError, EntityName] =
      AwsError.unwrapOptionField("dataSourceName", dataSourceName)
    def getRdsData: ZIO[
      Any,
      Nothing,
      zio.aws.machinelearning.model.RDSDataSpec.ReadOnly
    ] = ZIO.succeed(rdsData)
    def getRoleARN: ZIO[Any, Nothing, RoleARN] = ZIO.succeed(roleARN)
    def getComputeStatistics: ZIO[Any, AwsError, ComputeStatistics] =
      AwsError.unwrapOptionField("computeStatistics", computeStatistics)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.machinelearning.model.CreateDataSourceFromRdsRequest
  ) extends zio.aws.machinelearning.model.CreateDataSourceFromRdsRequest.ReadOnly {
    override val dataSourceId: EntityId =
      zio.aws.machinelearning.model.primitives.EntityId(impl.dataSourceId())
    override val dataSourceName: Optional[EntityName] = zio.aws.core.internal
      .optionalFromNullable(impl.dataSourceName())
      .map(value => zio.aws.machinelearning.model.primitives.EntityName(value))
    override val rdsData: zio.aws.machinelearning.model.RDSDataSpec.ReadOnly =
      zio.aws.machinelearning.model.RDSDataSpec.wrap(impl.rdsData())
    override val roleARN: RoleARN =
      zio.aws.machinelearning.model.primitives.RoleARN(impl.roleARN())
    override val computeStatistics: Optional[ComputeStatistics] =
      zio.aws.core.internal
        .optionalFromNullable(impl.computeStatistics())
        .map(value =>
          zio.aws.machinelearning.model.primitives.ComputeStatistics(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.machinelearning.model.CreateDataSourceFromRdsRequest
  ): zio.aws.machinelearning.model.CreateDataSourceFromRdsRequest.ReadOnly =
    new Wrapper(impl)
}
